changeset 11011:c3af543e6259

(display_mode_line): Rename perdisplay to kboard.
author Karl Heuer <kwzh@gnu.org>
date Wed, 15 Mar 1995 01:50:20 +0000
parents 45ae0022c48a
children 31d88266ed12
files src/xdisp.c
diffstat 1 files changed, 6 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/src/xdisp.c	Wed Mar 15 01:49:59 1995 +0000
+++ b/src/xdisp.c	Wed Mar 15 01:50:20 1995 +0000
@@ -2966,18 +2966,18 @@
   w->column_number_displayed = Qnil;
 
   get_display_line (f, vpos, left);
-#ifdef MULTI_PERDISPLAY
+#ifdef MULTI_KBOARD
   {
     /* Sigh, mode-line-format can reference display-local variables like
        defining-kbd-macro.  Use the one associated with the frame we're
        updating.  */
-    PERDISPLAY *orig_perdisplay = current_perdisplay;
-    current_perdisplay = get_perdisplay (f);
+    KBOARD *orig_kboard = current_kboard;
+    current_kboard = FRAME_KBOARD (f);
 #endif
     display_mode_element (w, vpos, left, 0, right, right,
 			  current_buffer->mode_line_format);
-#ifdef MULTI_PERDISPLAY
-    current_perdisplay = orig_perdisplay;
+#ifdef MULTI_KBOARD
+    current_kboard = orig_kboard;
   }
 #endif
   FRAME_DESIRED_GLYPHS (f)->bufp[vpos] = 0;
@@ -2966,18 +2966,18 @@
   {
-    /* Sigh, mode-line-format can reference display-local variables like
+    /* Sigh, mode-line-format can reference kboard-local variables like
        defining-kbd-macro.  Use the one associated with the frame we're
        updating.  */